﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.IO;


namespace RTFConvertor
{
    public static class Extension
    {
        public static string RTF(this RichTextBox richTextBox)
        {
            string rtf = string.Empty;
            TextRange textRange = new TextRange(richTextBox.Document.ContentStart, richTextBox.Document.ContentEnd);
            using (MemoryStream ms = new MemoryStream())
            {
                textRange.Save(ms, System.Windows.DataFormats.Rtf);
                ms.Seek(0, SeekOrigin.Begin);
                StreamReader sr = new StreamReader(ms);
                rtf = sr.ReadToEnd();
            }

            return rtf;
        }

        public static void LoadFromRTF(this RichTextBox richTextBox, string rtf)
        {
            if (string.IsNullOrEmpty(rtf))
            {
                throw new ArgumentNullException();
            }
            TextRange textRange = new TextRange(richTextBox.Document.ContentStart, richTextBox.Document.ContentEnd);
            using (MemoryStream ms = new MemoryStream())
            {
                using (StreamWriter sw = new StreamWriter(ms))
                {
                    sw.Write(rtf);
                    sw.Flush();
                    ms.Seek(0, SeekOrigin.Begin);
                    textRange.Load(ms, DataFormats.Rtf);
                }
            }
        }

        public static void SaveFile(this RichTextBox richTextBox, string filename)
        {
            if (string.IsNullOrEmpty(filename))
            {
                throw new ArgumentNullException();
            }

            // open the file for reading
            using (FileStream stream = File.OpenWrite(filename))
            {
                // create a TextRange around the entire document
                TextRange documentTextRange = new TextRange(richTextBox.Document.ContentStart, richTextBox.Document.ContentEnd);

                // sniff out what data format you've got
                string dataFormat = DataFormats.Text;
                string ext = System.IO.Path.GetExtension(filename);
                if (String.Compare(ext, ".xaml", true) == 0)
                {
                    dataFormat = DataFormats.Xaml;
                }
                else if (String.Compare(ext, ".rtf", true) == 0)
                {
                    dataFormat = DataFormats.Rtf;
                }
                documentTextRange.Save(stream, dataFormat);
            }
        }

        public static System.Drawing.FontStyle DrawingFontStyle(this RichTextBox richTextBox)
        {
            System.Drawing.FontStyle style = System.Drawing.FontStyle.Regular;
            object decoration = richTextBox.Selection.GetPropertyValue(Inline.TextDecorationsProperty);
            if (System.Windows.DependencyProperty.UnsetValue != decoration)
            {
                System.Windows.TextDecorationCollection textDecoration = decoration as System.Windows.TextDecorationCollection;
                style = style | textDecoration.ToFontStyle();
            }

            return style;
        }

        public static System.Drawing.FontStyle ToFontStyle(this System.Windows.TextDecorationCollection textDecorationCollection)
        {
            if (textDecorationCollection == System.Windows.TextDecorations.Underline)
                return System.Drawing.FontStyle.Underline;
            else if (textDecorationCollection == System.Windows.TextDecorations.Strikethrough)
                return System.Drawing.FontStyle.Strikeout;

            if (textDecorationCollection.Count > 0)
            {
                System.Drawing.FontStyle style = System.Drawing.FontStyle.Regular;
                foreach (var textDecoration in textDecorationCollection)
                {
                    switch (textDecoration.Location)
                    {
                        case TextDecorationLocation.Underline:
                            style |= System.Drawing.FontStyle.Underline;
                            break;
                        case TextDecorationLocation.Strikethrough:
                            style |= System.Drawing.FontStyle.Strikeout;
                            break;
                        default:
                            break;
                    }
                }

                return style;
            }

            return System.Drawing.FontStyle.Regular;
        }
    }
}
